@@ -491,7 +491,7 @@ class PostgresSourceConnector(C8Connector):
             schema = Schema(stream['stream'], s_attribs)
             results.append(Sample(
                 schema=schema,
-                data=fetch_samples(config, stream))
+                data=fetch_samples(config, stream)[:10])
             )
         return results
 
@@ -514,7 +514,7 @@ class PostgresSourceConnector(C8Connector):
         if source_type == 'string':
             return SchemaAttributeType.STRING
         elif source_type == 'integer':
-            return SchemaAttributeType.INT
+            return SchemaAttributeType.LONG
         elif source_type == 'boolean':
             return SchemaAttributeType.BOOLEAN
         elif source_type == 'number':
